@@ -4,7 +4,7 @@ xlwings - Make Excel fly with Python!
 Homepage and documentation: http://xlwings.org
 See also: http://zoomeranalytics.com
 
-Copyright (C) 2014, Zoomer Analytics LLC.
+Copyright (C) 2014-2015, Zoomer Analytics LLC.
 All rights reserved.
 
 License: BSD 3-clause (see LICENSE.txt for details)
@@ -43,7 +43,7 @@ class Workbook(object):
             self.xl_workbook = xl_workbook
             self.xl_app = xlplatform.get_app(self.xl_workbook)
         elif fullname:
-            self.fullname = fullname.lower()
+            self.fullname = fullname
             if xlplatform.is_file_open(self.fullname):
                 # Connect to an open Workbook
                 self.xl_app, self.xl_workbook = xlplatform.get_workbook(self.fullname)
@@ -67,23 +67,56 @@ class Workbook(object):
 
         ``wb = Workbook.caller()``
 
-        When called from Excel, always pack the ``Workbook`` call into the function being called from Excel, e.g.:
+        Always pack the ``Workbook`` call into the function being called from Excel, e.g.:
 
         .. code-block:: python
 
              def my_macro():
                 wb = Workbook.caller()
                 Range('A1').value = 1
+
+        To be able to easily invoke such code from Python for debugging, use ``Workbook.set_mock_caller()``.
         """
-        if len(sys.argv) > 2 and sys.argv[2] == 'from_xl':
+        if hasattr(Workbook, '_mock_file'):
+            # Use mocking Workbook, see Workbook.set_mock_caller()
+            xl_workbook = xlplatform.get_xl_workbook_from_xl(Workbook._mock_file)
+            return cls(xl_workbook=xl_workbook)
+        elif len(sys.argv) > 2 and sys.argv[2] == 'from_xl':
             # Connect to the workbook from which this code has been invoked
             fullname = sys.argv[1].lower()
-            return cls(fullname)
+            xl_workbook = xlplatform.get_xl_workbook_from_xl(fullname)
+            return cls(xl_workbook=xl_workbook)
         elif xlplatform.get_xl_workbook_current():
             # Called through ExcelPython connection
             return cls(xl_workbook=xlplatform.get_xl_workbook_current())
         else:
-            raise Exception('Workbook.caller() must not be called directly in Python but only through Excel.')
+            raise Exception('Workbook.caller() must not be called directly. Call through Excel or set a mock caller '
+                            'first with Workbook.set_mock_caller().')
+
+    @staticmethod
+    def set_mock_caller(fullpath):
+        """
+        Sets the Excel file which is used to mock ``Workbook.caller()`` when the code is called from within Python.
+
+        Examples
+        --------
+        ::
+
+            # This code runs unchanged from Excel and Python directly
+            import os
+            from xlwings import Workbook, Range
+
+            def my_macro():
+                wb = Workbook.caller()
+                Range('A1').value = 'Hello xlwings!'
+
+            if __name__ == '__main__':
+                # Mock the calling Excel file
+                Workbook.set_mock_caller(r'C:\\path\\to\\file.xlsx')
+
+                my_macro()
+        """
+        Workbook._mock_file = fullpath
 
     @classmethod
     def current(cls):
@@ -125,6 +158,25 @@ class Workbook(object):
         """Closes the Workbook without saving it."""
         xlplatform.close_workbook(self.xl_workbook)
 
+    def save(self, path=None):
+        """
+        Saves the Workbook under the specified path. If no path is specified, it's being saved in the current
+        working directory with the current filename.
+
+        Arguments
+        ---------
+        path : str, default None
+            Full path to the workbook
+
+        Example
+        -------
+        >>> from xlwings import Workbook
+        >>> wb = Workbook()
+        >>> wb.save(r'C:\\path\\to\\file.xlsx')
+
+        """
+        xlplatform.save_workbook(self.xl_workbook, path)
+
     @staticmethod
     def get_xl_workbook(wkb):
         """
